@@ -1,8 +1,12 @@
 
 `%||%` <-  function(l, r) if (is.null(l)) r else l
 
+`%&&%` <- function(l, r) if (is.null(l)) NULL else r
+
 not_null <- function(x) x[!map_lgl(x, is.null)]
 
+not_zchar <- function(x) x[x != ""]
+
 map_chr <- function(.x, .f, ...) {
   vapply(X = .x, FUN = .f, FUN.VALUE = character(1), ...)
 }
@@ -39,6 +43,11 @@ str_strip <- function(x) {
   sub("\\s+$", "", sub("^\\s+", "", x))
 }
 
+str_tail <- function(x, num) {
+  nc  <- nchar(x)
+  substr(x, pmax(nc - num + 1, 1), nc)
+}
+
 r_version <- function(x) {
   v <- paste0(version[["major"]], ".", version[["minor"]])
   package_version(v)
@@ -94,37 +103,10 @@ waitpid <- function(pid) {
   if (ps_os_type()[["POSIX"]]) .Call(psp__waitpid, as.integer(pid))
 }
 
-## nocov start
 caps <- function(x) {
   paste0(toupper(substr(x, 1, 1)), tolower(substr(x, 2, nchar(x))))
 }
 
-decorate_examples <- function(text, os = NULL) {
-  text <- gsub("\n\n", "\n", text)
-
-  if (!ps_is_supported()) {
-    text <- paste0(
-      "## ps does not support this platform, and cannot run the examples\n",
-      "## Currently supported platforms are ", supported_str(), ".\n",
-      ## "\\dontrun{",
-      text
-      ## "}"
-    )
-
-  } else if (!is.null(os) && !ps_os_type()[[os]]) {
-    text <- paste0(
-      "## these examples only work on ", caps(os), "\n",
-      ## "\\dontrun{",
-      text
-      ##"}"
-    )
-  }
-
-  ## paste0("\\examples{\n", text, "}")
-  paste0("\\preformatted{", text, "}")
-}
-## nocov end
-
 assert_string <- function(x) {
   if (is.character(x) && length(x) == 1 && !is.na(x)) return()
   stop(ps__invalid_argument(match.call()$x,
@@ -186,3 +168,7 @@ get_tool <- function(prog) {
   }
   exe
 }
+
+match_names <- function(map, x) {
+  names(map)[match(x, map)]
+}
